@@ -125,6 +125,10 @@ OPTIMIZER_RUNS_FOLDER = "optimizer"
 # OS
 PLATFORM_DATA_SEPARATOR = ":"
 CLOCK_REFRESH_HOURS_INTERVAL = int(os.getenv("CLOCK_REFRESH_HOURS_INTERVAL", "4"))
+RESOURCES_WATCHER_MINUTES_INTERVAL = int(
+    os.getenv("RESOURCES_WATCHER_MINUTES_INTERVAL", "10")
+)
+BYTES_BY_GB = 1000000000
 
 # Evaluators
 MIN_EVAL_TIME_FRAME = enums.TimeFrames.ONE_MINUTE
